@@ -122,8 +122,10 @@ gsd_wacom_stylus_finalize (GObject *object)
 }
 
 static const char *
-get_icon_name_from_type (WacomStylusType type)
+get_icon_name_from_type (const WacomStylus *wstylus)
 {
+	WacomStylusType type = libwacom_stylus_get_type (wstylus);
+
 	switch (type) {
 	case WSTYLUS_INKING:
 	case WSTYLUS_STROKE:
@@ -137,6 +139,8 @@ get_icon_name_from_type (WacomStylusType type)
 	case WSTYLUS_CLASSIC:
 		return "wacom-stylus-classic";
 	default:
+		if (!libwacom_stylus_has_eraser (wstylus))
+			return "wacom-stylus-no-eraser";
 		return "wacom-stylus";
 	}
 }
@@ -158,7 +162,7 @@ gsd_wacom_stylus_new (GsdWacomDevice    *device,
 	stylus->priv->name = g_strdup (libwacom_stylus_get_name (wstylus));
 	stylus->priv->settings = settings;
 	stylus->priv->type = libwacom_stylus_get_type (wstylus);
-	stylus->priv->icon_name = get_icon_name_from_type (stylus->priv->type);
+	stylus->priv->icon_name = get_icon_name_from_type (wstylus);
 	stylus->priv->has_eraser = libwacom_stylus_has_eraser (wstylus);
 	stylus->priv->num_buttons = libwacom_stylus_get_num_buttons (wstylus);
 
@@ -1424,7 +1428,8 @@ gsd_wacom_device_constructor (GType                     type,
 												n_construct_properties,
 												construct_properties));
 
-	if (device->priv->gdk_device == NULL)
+	if (device->priv->gdk_device == NULL ||
+	    !GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
 		return G_OBJECT (device);
 
 	device_manager = gdk_display_get_device_manager (gdk_display_get_default ());
@@ -2103,6 +2108,12 @@ gsd_wacom_device_rotation_type_to_name (GsdWacomRotation type)
 	return "none";
 }
 
+GdkDevice *
+gsd_wacom_device_get_gdk_device (GsdWacomDevice *device)
+{
+	return device->priv->gdk_device;
+}
+
 GsdWacomDevice *
 gsd_wacom_device_create_fake (GsdWacomDeviceType  type,
 			      const char         *name,
